@@ -20,8 +20,8 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_QUERYITERATOR_P_H
-#define AKONADI_SEARCH_PIM_QUERYITERATOR_P_H
+#ifndef AKONADI_SEARCH_PIM_RESULTITERATOR_P_H
+#define AKONADI_SEARCH_PIM_RESULTITERATOR_P_H
 
 #include "resultiterator.h"
 #include "xapian.h"
@@ -55,4 +55,4 @@ public:
 }
 }
 
-#endif // AKONADI_SEARCH_PIM_QUERYITERATOR_P_H
+#endif // AKONADI_SEARCH_PIM_RESULTITERATOR_P_H
